@@ -1,7 +1,8 @@
 package constant::Atom;
 
-use strict; use warnings;
-our $VERSION = '0.02';
+use strict;
+use warnings;
+our $VERSION = '0.03';
 
 use Carp;
 sub new {
@@ -203,6 +204,8 @@ Output: Can't cast Atom::Strict object 'main::myatom' into a string.  Use the 'f
 
 =head1 OTHER METHODS
 
+=over 4
+
 =item C<name>
 
 	package Languages;
@@ -225,10 +228,16 @@ Output: English
 	
 Output: Languages::English
 
+=back
+
 =head1 SEE ALSO
 
 C<constant>
 
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/constant-Atom>
+
 =head1 AUTHOR
 
 This module was originally created by Jonathan R. Warden E<lt>john@newchester.comE<gt>,
